@@ -1641,7 +1641,7 @@ else if(font_num == times)
 
 int direct_ps_plot(void)
 {
-char *p;
+char *p, *q;
 
 choix = show_tree;
 /* read tree file */
@@ -1650,7 +1650,8 @@ if( (p = preptree(fname) ) != NULL ) {
 	return 1;
 	}
 strcpy(plotfilename, fname);
-p = strchr(plotfilename, '.'); 
+q = extract_filename(plotfilename);
+p = strchr(q, '.'); 
 if(p == NULL) p = plotfilename + strlen(plotfilename);
 #ifdef TTY
 strcpy(p, ".txt");
@@ -1741,7 +1742,8 @@ for(num = 1; num < *argc; num++) {
 #else
 "-us            postcript tree file prepared for US Letter paper size\n"
 #ifndef NO_GUI
-"-psonly        no window interface, just write the postscript tree file\n"
+"-psonly        no window interface, just write the postscript tree plot\n"
+"               to file named as input tree file with .ps extension\n"
 "-red xxxx      highlight in red all taxon names containing string xxxx\n"
 #endif
 "-pc n          number of pages for PostScript output\n"
@@ -1855,7 +1857,9 @@ physx = 120; /* default width of text output */
 for(num = 1; num < *argc; num++) {
 	if( strncmp(argv[num], "-txtw", 5) == 0) {
 		if(num + 1 < *argc) {
-			sscanf(argv[num+1], "%d", &physx);
+			int val;
+			sscanf(argv[num+1], "%d", &val);
+			physx = (double)val;
 			remove_arg(num + 1, argc, argv);
 			}
 		remove_arg(num, argc, argv);
@@ -2647,7 +2651,7 @@ else	{
 if(notu+1<3) return ("Tree should contain at least 3 elements.");
 subtree_notu = notu;
 #ifndef NO_GUI
-scrollnotu(notu);
+if(!ps_plot_only) scrollnotu(notu);
 #endif
 return NULL;
 
@@ -2915,7 +2919,10 @@ while(p < fin) {
 		}
 	p++;
 	}
-if(virg > 1) {
+if(virg > 1) { /* multifurcation */
+	/* make sure tree has branch lengths */
+	if( memchr(debut, ':', fin - debut + 1) == NULL) 
+		bad_format("Cannot process multibranched tree without branch lengths");
 	/* recherche de la 2eme virgule */
 	p = debut; l = 0;
 	while(TRUE) {
@@ -3711,6 +3718,16 @@ physx = ps_width;
 physy = sheets_h;
 
 plotfile=fopen(plotfilename,"w");
+if(plotfile == NULL) {
+	char tmp[300];
+	sprintf(tmp, "Error opening %s for writing\n", plotfilename);
+#ifndef NO_GUI
+	err_message(tmp);
+#else
+	fputs(tmp, stderr);
+#endif
+	exit(1);
+	}
 fprintf(plotfile,"%%!PS-Adobe-1.0\n"
 	"%%%%DocumentFonts: Times-Roman %s\n"
 	"%%%%Creator: njplot\n"
